@@ -8,7 +8,7 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2018, 2021 The Sympa Community. See the
+# Copyright 2018, 2021, 2023 The Sympa Community. See the
 # AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
@@ -386,28 +386,23 @@ sub add_field {
     return $report;
 }
 
-sub delete_field {
+sub drop_field {
+    $log->syslog('debug', '(%s, %s, %s)', @_);
     my $self  = shift;
-    my $param = shift;
-    $log->syslog('debug', 'Deleting field %s from table %s',
-        $param->{'field'}, $param->{'table'});
+    my $table = shift;
+    my $field = shift;
 
     unless (
-        $self->do_query(
-            "ALTER TABLE %s DROP COLUMN %s", $param->{'table'},
-            $param->{'field'}
-        )
+        $self->do_query(q{ALTER TABLE %s DROP COLUMN %s}, $table, $field)
     ) {
         $log->syslog('err',
             'Could not delete field %s from table %s in database %s',
-            $param->{'field'}, $param->{'table'}, $self->{'db_name'});
+            $field, $table, $self->{'db_name'});
         return undef;
     }
 
-    my $report = sprintf('Field %s removed from table %s',
-        $param->{'field'}, $param->{'table'});
-    $log->syslog('info', 'Field %s removed from table %s',
-        $param->{'field'}, $param->{'table'});
+    my $report = sprintf 'Field %s removed from table %s', $field, $table;
+    $log->syslog('info', '%s', $report);
 
     return $report;
 }
