@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -8,7 +7,7 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017, 2018, 2019, 2021 The Sympa Community. See the
+# Copyright 2017, 2018, 2019, 2021, 2022 The Sympa Community. See the
 # AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
@@ -73,9 +72,13 @@ sub _twist {
 
         $list->add_list_member(
             {   email => $email,
+                (   defined $request->{custom_attribute}
+                    ? (attrib => $request->{custom_attribute})
+                    : ()
+                ),
                 map { ($_ => $request->{$_}) }
                     grep { defined $request->{$_} }
-                    qw(gecos reception visibility custom_attribute)
+                    qw(gecos reception visibility)
             },
             stash => \@stash
         );
@@ -171,9 +174,17 @@ sub _report_user {
     my $role   = $request->{role};
     my $email  = $request->{email};
     my $sender = $request->{sender};
+    my $reception;
+
+    if (exists $request->{reception}) {
+        $reception = $request->{reception};
+    }
+    else {
+        $reception = $list->get_default_user_options(role => $role)->{reception};
+    }
 
     # Notify the new list owner/editor
-    unless ($request->{quiet}) {
+    unless ($request->{quiet} or $reception eq 'nomail') {
         Sympa::send_notify_to_user($list, 'added_as_listadmin', $email,
             {admin_type => $role, delegator => $sender});
         $self->add_stash($request, 'notice', 'user_notified',
