@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -8,8 +7,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017, 2019, 2021 The Sympa Community. See the AUTHORS.md
-# file at the top-level directory of this distribution and at
+# Copyright 2017, 2019, 2021, 2022 The Sympa Community. See the
+# AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -176,15 +175,25 @@ sub _twist {
     my $message = shift;
 
     # Get list/robot context.
-    my ($list, $robot, $listname);
+    my ($list, $robot, $listname, $arc_enabled, $dkim_enabled);
     if (ref($message->{context}) eq 'Sympa::List') {
         $list     = $message->{context};
         $robot    = $message->{context}->{'domain'};
         $listname = $list->{'name'};
+
+        $arc_enabled = 'on' eq $list->{'admin'}{'arc_feature'};
+        $dkim_enabled =
+            'on' eq Conf::get_robot_conf($list->{'domain'}, 'dkim_feature');
     } elsif ($message->{context} and $message->{context} ne '*') {
         $robot = $message->{context};
+
+        $arc_enabled  = 'on' eq Conf::get_robot_conf($robot, 'arc_feature');
+        $dkim_enabled = 'on' eq Conf::get_robot_conf($robot, 'dkim_feature');
     } else {
         $robot = '*';
+
+        $arc_enabled  = 'on' eq $Conf::Conf{'arc_feature'};
+        $dkim_enabled = 'on' eq $Conf::Conf{'dkim_feature'};
     }
 
     if ($message->{serial} eq '0' or $message->{serial} eq 's') {
@@ -225,12 +234,13 @@ sub _twist {
         $message->dmarc_protect;
     }
 
-    my ($dkim, $arc);
-    if ($message->{shelved}{dkim_sign}) {
-        $dkim = Sympa::Tools::DKIM::get_dkim_parameters($message->{context});
-        $arc  = Sympa::Tools::DKIM::get_arc_parameters($message->{context})
-            if $message->{shelved}->{arc_cv};
-    }
+    my %arc =
+        Sympa::Tools::DKIM::get_arc_parameters($message->{context},
+        $message->{shelved}{arc_cv})
+        if $arc_enabled and $message->{shelved}{arc_cv};
+    my %dkim = Sympa::Tools::DKIM::get_dkim_parameters($message->{context})
+        if %arc
+        or $message->{shelved}{dkim_sign};
 
     if (   $message->{shelved}{merge}
         or $message->{shelved}{smime_encrypt}
@@ -280,6 +290,15 @@ sub _twist {
                 $return_path = Sympa::get_address($robot, 'owner');
             }
 
+            # If message is personalized and DKIM signature is available,
+            # Add One-Click Unsubscribe header field.
+            if (    $new_message->{shelved}{merge}
+                and (%arc or $new_message->{shelved}{dkim_sign} and %dkim)
+                and grep { 'unsubscribe' eq $_ }
+                @{$list->{'admin'}{'rfc2369_header_fields'}}) {
+                $list->add_list_header($new_message, 'unsubscribe',
+                    oneclick => $rcpt);
+            }
             if (    $new_message->{shelved}{merge}
                 and $new_message->{shelved}{merge} ne 'footer') {
                 unless ($new_message->personalize($list, $rcpt)) {
@@ -329,27 +348,16 @@ sub _twist {
                 delete $new_message->{shelved}{smime_encrypt};
             }
 
-            if (Conf::get_robot_conf($robot, 'dkim_feature') eq 'on') {
-                $new_message->remove_invalid_dkim_signature;
-            }
-            if ($new_message->{shelved}{dkim_sign} and $dkim) {
+            $new_message->remove_invalid_dkim_signature
+                if $arc_enabled or $dkim_enabled;
+
+            my $arc_sealed = $new_message->arc_seal(%arc) if %arc;
+
+            if ($new_message->{shelved}{dkim_sign} or $arc_sealed) {
                 # apply DKIM signature AFTER any other message
                 # transformation.
-                $new_message->dkim_sign(
-                    'dkim_d'          => $dkim->{'d'},
-                    'dkim_i'          => $dkim->{'i'},
-                    'dkim_selector'   => $dkim->{'selector'},
-                    'dkim_privatekey' => $dkim->{'private_key'},
-                );
-
-                $new_message->arc_seal(
-                    'arc_d'          => $arc->{'d'},
-                    'arc_selector'   => $arc->{'selector'},
-                    'arc_srvid'      => $arc->{'srvid'},
-                    'arc_privatekey' => $arc->{'private_key'},
-                    'arc_cv'         => $message->{shelved}->{arc_cv}
-
-                ) if $arc;
+                # Note that when ARC seal was added, DKIM signature is forced.
+                $new_message->dkim_sign(%dkim) if %dkim;
 
                 delete $new_message->{shelved}{dkim_sign};
             }
@@ -394,24 +402,14 @@ sub _twist {
             delete $new_message->{shelved}{smime_sign};
         }
 
-        if (Conf::get_robot_conf($robot, 'dkim_feature') eq 'on') {
-            $new_message->remove_invalid_dkim_signature;
-        }
+        $new_message->remove_invalid_dkim_signature
+            if $arc_enabled or $dkim_enabled;
+
+        my $arc_sealed = $new_message->arc_seal(%arc) if %arc;
+
         # Initial message
-        if ($new_message->{shelved}{dkim_sign} and $dkim) {
-            $new_message->dkim_sign(
-                'dkim_d'          => $dkim->{'d'},
-                'dkim_i'          => $dkim->{'i'},
-                'dkim_selector'   => $dkim->{'selector'},
-                'dkim_privatekey' => $dkim->{'private_key'},
-            );
-            $new_message->arc_seal(
-                'arc_d'          => $arc->{'d'},
-                'arc_selector'   => $arc->{'selector'},
-                'arc_srvid'      => $arc->{'srvid'},
-                'arc_privatekey' => $arc->{'private_key'},
-                'arc_cv'         => $message->{shelved}->{arc_cv}
-            ) if $arc;
+        if ($new_message->{shelved}{dkim_sign} or $arc_sealed) {
+            $new_message->dkim_sign(%dkim) if %dkim;
 
             delete $new_message->{shelved}{dkim_sign};
         }
