@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -8,7 +7,7 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2020 The Sympa Community. See the AUTHORS.md
+# Copyright 2020, 2022 The Sympa Community. See the AUTHORS.md
 # file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
@@ -95,20 +94,9 @@ sub _twist {
         Time::HiRes::time() - $self->{start_time}
     );
 
-    # Do not report to the sender if the message was tagged as a spam.
-    unless ($self->{quiet} or $message->{'spam_status'} eq 'spam') {
-        # Ensure 1 second elapsed since last message.
-        Sympa::send_file(
-            $list,
-            'message_report',
-            $sender,
-            {   type           => 'success',              # Comapt. <=6.2.12.
-                entry          => 'moderating_message',
-                auto_submitted => 'auto-replied'
-            },
-            date => time + 1
-        );
-    }
+    Sympa::send_dsn($list, $message, {}, '4.3.0')
+        unless $self->{quiet}
+        or $message->{'spam_status'} eq 'spam';
     return 1;
 }
 
@@ -122,14 +110,10 @@ sub _send_confirm_to_editor {
     my $list = $message->{context};
     my $spool_mod = Sympa::Spool::Moderation->new(context => $list);
 
-    my $modkey;
     # Keeps a copy of the message.
     # Move message to mod spool.
-    # If crypted, store the crypted form of the message (keep decrypted
-    # form for HTML view).
-    if ($modkey = $spool_mod->store($message, original => 1)) {
-        $spool_mod->html_store($message, $modkey);
-    }
+    # If crypted, store the crypted form of the message.
+    my $modkey = $spool_mod->store($message, original => 1);
     unless ($modkey) {
         $log->syslog('err', 'Cannot create moderation key of %s for %s',
             $message, $list);
