@@ -311,6 +311,7 @@ sub sort_uniq {
 # Old name: Sympa::List::parseCustomAttribute().
 sub decode_custom_attribute {
     my $xmldoc = shift;
+
     return undef unless defined $xmldoc and length $xmldoc;
 
     my $parser = XML::LibXML->new();
@@ -332,31 +333,33 @@ sub decode_custom_attribute {
     foreach my $ca (@custom_attr) {
         my $id    = Encode::encode_utf8($ca->getAttribute('id'));
         my $value = Encode::encode_utf8($ca->getElementsByTagName('value'));
-        $ca{$id} = {value => $value};
+        $ca{$id} = $value;
     }
+
     return \%ca;
 }
 
 # Old name: Sympa::List::createXMLCustomAttribute().
 sub encode_custom_attribute {
-    my $custom_attr = shift;
+    my $ca = shift;
+
     return
         '<?xml version="1.0" encoding="UTF-8" ?><custom_attributes></custom_attributes>'
-        if (not defined $custom_attr);
-    my $XMLstr = '<?xml version="1.0" encoding="UTF-8" ?><custom_attributes>';
-    foreach my $k (sort keys %{$custom_attr}) {
-        my $value = $custom_attr->{$k}{value};
-        $value = '' unless defined $value;
+        unless $ca;
+    my $ret =
+        '<?xml version="1.0" encoding="UTF-8" ?><custom_attributes>' . join(
+        '',
+        map {
+            sprintf
+                '<custom_attribute id="%s"><value>%s</value></custom_attribute>',
+                $_,
+                Sympa::Tools::Text::encode_html($ca->{$_} // '', '\000-\037');
+            }
+            sort keys %$ca
+        ) . '</custom_attributes>';
+    $ret =~ s/\s*\n\s*/ /g;
 
-        $XMLstr .=
-              "<custom_attribute id=\"$k\"><value>"
-            . Sympa::Tools::Text::encode_html($value, '\000-\037')
-            . "</value></custom_attribute>";
-    }
-    $XMLstr .= "</custom_attributes>";
-    $XMLstr =~ s/\s*\n\s*/ /g;
-
-    return $XMLstr;
+    return $ret;
 }
 
 my $language = Sympa::Language->instance;
@@ -507,7 +510,7 @@ XML formed data as stored in database
 
 Returns:
 
-A hashref storing custome attributes.
+A hashref storing custom attributes.
 
 =item diff_on_arrays ( $setA, $setB )
 
@@ -563,7 +566,7 @@ Options:
 
 =item $hasref
 
-Hashref storing custome attributes.
+Hashref storing custom attributes.
 
 =back
 
@@ -620,7 +623,7 @@ Returns:
 
 Formatted string.
 
-This was introduced on Sympa 6.2.69b.
+This was introduced on Sympa 6.2.70.
 
 =item get_array_from_splitted_string ($string)
 
@@ -643,7 +646,7 @@ An arrayref.
 
 =item hash_2_string (...)
 
-Converts a hash into a string formated as var1="value1";var2="value2"; into
+Converts a hash into a string formatted as var1="value1";var2="value2"; into
 a hash.
 TBD.
 
@@ -699,7 +702,7 @@ If arguments matched, true value.  Otherwise false value.
 
 =item smart_lessthan (...)
 
-Compares two scalars, string/numeric independant.
+Compares two scalars, string/numeric independent.
 TBD.
 
 =item sort_uniq ( [ \&comp ], @items )
@@ -725,7 +728,7 @@ This function was added on Sympa 6.2.16.
 
 =item string_2_hash (...)
 
-Converts a string formated as var1="value1";var2="value2"; into a hash.
+Converts a string formatted as var1="value1";var2="value2"; into a hash.
 Used when extracting from session table some session properties or when
 extracting users preference from user table.
 Current encoding is NOT compatible with encoding of values with '"'.
