@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -8,7 +7,7 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2018, 2019, 2021 The Sympa Community. See the
+# Copyright 2018, 2019, 2021, 2022 The Sympa Community. See the
 # AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
@@ -163,7 +162,7 @@ sub authentication {
             # Old style RC4 encrypted password.
             if ($user->{'password'} and $user->{'password'} =~ /\Acrypt[.]/) {
                 $log->syslog('notice',
-                    'Password in database seems encrypted. Run upgrade_sympa_password.pl to rehash passwords'
+                    'Password in database seems encrypted. Run \'sympa upgrade password\' to rehash passwords'
                 );
                 Sympa::send_notify_to_listmaster('*', 'password_encrypted',
                     {});
